// @ts-check
import React from 'react';
import { connect } from 'react-redux';
import PropTypes from 'prop-types';
import { compose, setPropTypes } from 'recompose';

import * as messageActions from '../../actions/messages';
import { getLatestRemote } from '../../utils/helpers';

var mapStateToProps = function mapStateToProps(_ref) {
    var messages = _ref.messages;

    var latestMessage = getLatestRemote(messages.messages);
    return {
        inputExpected: latestMessage && latestMessage.input_expected,
        buttons: latestMessage && latestMessage.buttons
    };
};

var mapDispatchToProps = function mapDispatchToProps(dispatch) {
    return {
        submitHandler: function submitHandler(text) {
            dispatch(messageActions.messageSend({
                text: text
            }));
        },
        onKeyDown: function onKeyDown(event, text) {
            if (event.keyCode === 13) {
                dispatch(messageActions.messageSend({
                    text: text
                }));
                return true;
            }
            return false;
        }
    };
};

var enhance = compose(setPropTypes({
    messages: PropTypes.object
}), connect(mapStateToProps, mapDispatchToProps));

export var InputArea = function InputArea(_ref2) {
    var InputComponent = _ref2.InputComponent,
        submitHandler = _ref2.submitHandler,
        onKeyDown = _ref2.onKeyDown,
        inputExpected = _ref2.inputExpected,
        MenuComponent = _ref2.MenuComponent,
        CheckboxMenuComponent = _ref2.CheckboxMenuComponent,
        buttons = _ref2.buttons;

    return React.createElement(
        'div',
        { className: 'ChatContainer-input' },
        inputExpected === 'radio' && React.createElement(MenuComponent, { items: buttons, submitHandler: submitHandler }),
        inputExpected === 'checkbox' && React.createElement(CheckboxMenuComponent, {
            items: buttons,
            submitHandler: submitHandler
        }),
        React.createElement(InputComponent, {
            onKeyDown: onKeyDown,
            submitHandler: submitHandler
        })
    );
};

export default enhance(InputArea);