var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

// @ts-check
import React from 'react';
import { connect } from 'react-redux';
import PropTypes from 'prop-types';

import AvatarContainer from '../AvatarContainer';
import MessageContainer from '../MessageContainer';
import Message from '../Message';

import * as messageActions from '../../actions/messages';

import Avatar from '../../../es/themes/default/components/Avatar/index';
import networkManager from '../../../es/utils/network';
import TypingIndicator from '../../../es/themes/default/components/TypingIndicator/index';

var mapStateToProps = function mapStateToProps(_ref) {
    var messages = _ref.messages,
        config = _ref.config;
    return {
        messages: messages.messages,
        messageQueue: messages.messageQueue,
        config: config
    };
};

var mapDispatchToProps = function mapDispatchToProps(dispatch, ownProps) {
    return {
        submitHandler: function submitHandler(message) {
            dispatch(messageActions.messageSend(_extends({}, message, {
                type: 'button'
            })));
        }
    };
};

var MessageList = function (_React$Component) {
    _inherits(MessageList, _React$Component);

    function MessageList(props) {
        _classCallCheck(this, MessageList);

        var _this = _possibleConstructorReturn(this, _React$Component.call(this, props));

        _this.state = {
            offset: 0
        };
        return _this;
    }

    MessageList.prototype.componentDidUpdate = function componentDidUpdate() {
        this._last && this._last.scrollIntoView({
            behavior: 'smooth',
            block: 'end',
            inline: 'end'
        });

        // let { messageQueue, delayedMessageAdd } = this.props;

        // messageQueue.length && delayedMessageAdd(messageQueue[messageQueue.length - 1]);
    };

    MessageList.prototype.render = function render() {
        var _this2 = this;

        var _props = this.props,
            theme = _props.theme,
            messages = _props.messages,
            messageQueue = _props.messageQueue,
            submitHandler = _props.submitHandler,
            config = _props.config;

        return React.createElement(
            'ul',
            {
                className: 'ChatContainer-content',
                ref: function ref(_ref3) {
                    return _this2._ref = _ref3;
                }
            },
            React.createElement(
                'div',
                { className: 'MessagesList' },
                messages.map(function (message, i) {
                    return React.createElement(
                        'li',
                        {
                            key: i,
                            ref: function ref(_ref2) {
                                if (i === messages.length - 1) {
                                    _this2._last = _ref2;
                                }
                            }
                        },
                        message.origin === 'remote' && (messages[i - 1] ? messages[i - 1].origin !== 'remote' : true) && React.createElement(AvatarContainer, {
                            AvatarComponent: theme.AvatarComponent
                        }),
                        React.createElement(
                            MessageContainer,
                            _extends({ key: 'text' }, message),
                            message.origin === 'remote' ? message.pages.map(function (page, i) {
                                return React.createElement(Message, _extends({
                                    key: i,
                                    page: page,
                                    isLocal: message.origin === 'local'
                                }, theme, {
                                    submitHandler: submitHandler
                                }));
                            }) : React.createElement(Message, _extends({
                                key: i,
                                page: { text: message.text },
                                isLocal: true
                            }, theme))
                        ),
                        ' ',
                        message.buttons && message.buttonStyle === 'default' && React.createElement(
                            MessageContainer,
                            _extends({
                                key: 'buttons'
                            }, message),
                            message.buttons.map(function (button, i) {
                                return React.createElement(theme.ButtonComponent, {
                                    key: i,
                                    text: button.text,
                                    phone: button.phone,
                                    url: button.url,
                                    onClick: function onClick() {
                                        return submitHandler({
                                            postback: button.postback,
                                            text: button.text
                                        });
                                    }
                                });
                            })
                        ),
                        messageQueue.length && i === messages.length - 1 && config.typingStatus.active ? [React.createElement(
                            MessageContainer,
                            { key: 'typing' },
                            React.createElement(theme.TypingIndicatorComponent, config.TypingIndicator)
                        )] : null
                    );
                })
            )
        );
    };

    return MessageList;
}(React.Component);

MessageList.PropTypes = {
    messages: PropTypes.object,
    theme: PropTypes.shape({
        ImageComponent: PropTypes.oneOfType([PropTypes.element, PropTypes.func]),
        InputComponent: PropTypes.oneOfType([PropTypes.element, PropTypes.func]),
        MessageComponent: PropTypes.oneOfType([PropTypes.element, PropTypes.func]),
        TextComponent: PropTypes.oneOfType([PropTypes.element, PropTypes.func])
    }),
    config: PropTypes.object
};

export default connect(mapStateToProps, mapDispatchToProps)(MessageList);