var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

import { createStoreWithState } from './store';
import { merge } from 'lodash';

import { Provider } from 'react-redux';
import 'smoothscroll-polyfill';

import ChatContainer from './components/ChatContainer';

import * as actionTypes from './actionTypes';
import RWCFeersumClient from 'rwc-feersum-client';
import NetworkManager from './utils/network';
import defaultTheme from './themes/default';
import defaultConfig from './config';

/**
 * The main react component for React Web Chat
 * @param {Object} params - An object containing configuration parameters
 * @param {Object} params.theme - Custom theme
 * @param {String} params.url - Chat server url to post messages to
 * @param {Object} params.client - Which client to use for network communication
 * @param {Object} params.typingStatus - A list of configuration options for the typing status indicator
 * @param {Object} params.network - A list of configuration options for network communication
 * @return {Object} React component
 */
export var ReactWebChatComponent = function ReactWebChatComponent(_ref) {
    var theme = _ref.theme,
        avatar = _ref.avatar,
        client = _ref.client,
        url = _ref.url,
        typingStatus = _ref.typingStatus,
        network = _ref.network;

    var store = createStoreWithState({
        config: merge({}, defaultConfig, { typingStatus: typingStatus }, { network: network }, { avatar: avatar })
    });
    var networkManager = new NetworkManager({
        store: store,
        client: client || new RWCFeersumClient({
            url: url,
            config: {
                channel_id: network.channel_id,
                address: network.address,
                startNew: network.startNew,
                retransmissionTimeout: network.retransmissionTimeout || 500,
                retransmissionMaxTimeout: network.retransmissionMaxTimeout,
                retransmissionAttempts: network.retransmissionAttempts,
                schemaVersion: network.schemaVersion
            }
        })
    });
    networkManager.init();
    return React.createElement(
        Provider,
        { store: store },
        React.createElement(ChatContainer, { theme: _extends({}, defaultTheme, theme) })
    );
};

/**
 * The wrapping constructor module which renders {@link ReactWebChatComponent} to the target element
 */

var ReactWebChat = function () {
    function ReactWebChat() {
        var _ref2 = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {
            theme: defaultTheme,
            avatar: avatar,
            client: client,
            element: element,
            url: 'http://localhost:8080/echo',
            typingStatus: typingStatus,
            network: network
        },
            theme = _ref2.theme,
            avatar = _ref2.avatar,
            client = _ref2.client,
            element = _ref2.element,
            url = _ref2.url,
            typingStatus = _ref2.typingStatus,
            network = _ref2.network;

        _classCallCheck(this, ReactWebChat);

        if (element && element.nodeName) {
            /**
             * @type {Element}
             */
            this.element = element;
            /**
             * @type {Object}
             */
            this.client = client;
            this.bindEventsToActions();
            ReactDOM.render(React.createElement(ReactWebChatComponent, {
                theme: theme,
                avatar: avatar || 'http://i.pravatar.cc/300',
                client: client,
                url: url,
                typingStatus: typingStatus,
                network: network
            }), element);
        } else {
            console.error('React Web Chat: expected element passed to constructor to be a DOM node. Received instead: ', element);
        }
    }

    ReactWebChat.prototype.bindEventsToActions = function bindEventsToActions() {
        Object.values(actionTypes).map(function (type) {
            return window.addEventListener('rwc-dispatch-' + type, function (_ref3) {
                var payload = _ref3.detail.payload;
                return store.dispatch({
                    type: type,
                    payload: payload
                });
            });
        });
    };

    return ReactWebChat;
}();

export default ReactWebChat;