// @ts-check
/**
 * Automatically dispatches custom events whenever a redux action is dispatched.
 * @param {Object} store - a redux store instance
 */
var eventEmitterMiddleware = function eventEmitterMiddleware(store) {
    return function (next) {
        return function (action) {
            var eventNamespace = store.getState().config.network.eventNamespace;

            var event = new CustomEvent(eventNamespace + "-" + action.type, {
                detail: {
                    payload: action.payload
                }
            });

            window.dispatchEvent(event);
            return next(action);
        };
    };
};

export default eventEmitterMiddleware;