import React from 'react';

/**
 * Renders the chat bot's avatar along with a status indicator. 
 * @param {Object} props
 * @param {string} props.avatar - A url to an image to use as the avatar.
 * @param {boolean} props.connecting - A state variable indicating that the chat app is busy attempting a connection to the server.
 * @param {boolean} props.established - A state variable indicating that the chat server is online and the handshake was successful.
 * @param {boolean} props.offline - A state variable indicating that the chat server is offline.
 * @param {boolean} props.typing - A state variable indicating that the chat app is currently simulating "typing..."
 * @return {Object} React component
 */
var Avatar = function Avatar(props) {
    return React.createElement(
        "div",
        { className: "AvatarStatus" },
        React.createElement(
            "div",
            { className: "AvatarStatus-avatar" },
            React.createElement("img", { className: "Avatar", src: props.avatar })
        ),
        React.createElement(
            "div",
            { className: "AvatarStatus-status" },
            switchIndicator(props)
        )
    );
};

/**
 * Toggles different indicator states based on connection state variable
 * @todo refactor this to use a map
 */
var switchIndicator = function switchIndicator(_ref) {
    var connecting = _ref.connecting,
        established = _ref.established,
        offline = _ref.offline,
        avatar = _ref.avatar,
        typing = _ref.typing;

    if (typing) {
        return React.createElement(StatusIndicator, { status: "typing" });
    } else {
        if (established) {
            return React.createElement(StatusIndicator, { status: "online" });
        }
        if (connecting) {
            return React.createElement(StatusIndicator, { status: "thinking" });
        }
        if (offline) {
            return React.createElement(StatusIndicator, { status: "offline" });
        }
    }
};

var StatusIndicator = function StatusIndicator(_ref2) {
    var status = _ref2.status;
    return React.createElement("div", {
        className: "StatusIndicator\n            " + (status ? "StatusIndicator--" + status : '') + "\n        "
    });
};

export default Avatar;