// @ts-check
import React from 'react';
import PropTypes from 'prop-types';
import { compose, setPropTypes, lifecycle } from 'recompose';
import { withState } from 'recompose';

import infinityIcon from '../../icons/Infinity.svg';
import { Fade } from '../Animation/index';

var enhance = compose(setPropTypes({
    url: PropTypes.string.isRequired,
    text: PropTypes.string,
    width: PropTypes.number,
    height: PropTypes.number
}), withState('loaded', 'setLoaded', false), lifecycle({
    componentDidMount: function componentDidMount(props) {
        var _this = this;

        var image = new Image(0, 0);
        image.src = this.props.url;
        image.addEventListener('load', function () {
            _this.setState({ loaded: true });
        });
    }
}));

/**
 * An image
 * @param {Object} param
 * @param {string} param.url - image url
 * @param {number} param.width - width of the image in pixels
 * @param {number} param.height - height of the image in pixels
 * @return {Object} React component
 */

export var ImageComponent = function ImageComponent(_ref) {
    var url = _ref.url,
        text = _ref.text,
        loaded = _ref.loaded,
        _ref$height = _ref.height,
        height = _ref$height === undefined ? 200 : _ref$height;

    return React.createElement(
        Fade,
        { 'in': true, appear: true },
        React.createElement(
            'div',
            { className: 'Image' },
            loaded ? React.createElement('img', { className: 'Image-image', src: url }) : React.createElement(
                'div',
                { className: 'Image-loader', style: { height: height } },
                React.createElement('img', { className: 'Image-loaderIcon', src: infinityIcon })
            ),
            text && React.createElement('p', { className: 'Image-text Text', dangerouslySetInnerHTML: { __html: text } })
        )
    );
};

export default enhance(ImageComponent);