// @ts-check
import React from 'react';
import PropTypes from 'prop-types';
import { compose, setPropTypes, withState } from 'recompose';

import Button from '../Button';

var enhance = compose(setPropTypes({
    submitHandler: PropTypes.func,
    onKeyDown: PropTypes.func
}), withState('value', 'setValue', ''));

/**
 * A simple text Input component.
 * @param {Object} param
 * @param {string|number} param.value - the input's value.
 * @param {function(text: string)} param.submitHandler - submit handler function. This will send a message to the server using data supplied as parameter
 * @return {Object} React component
 */
export var Input = function Input(_ref) {
    var submitHandler = _ref.submitHandler,
        _onKeyDown = _ref.onKeyDown,
        value = _ref.value,
        setValue = _ref.setValue;

    var _onClick = function _onClick(value) {
        submitHandler(value);
        setValue('');
    };
    return React.createElement(
        'div',
        {
            className: 'Input',
            onKeyDown: function onKeyDown(event) {
                var success = _onKeyDown(event, value);
                if (success) {
                    setValue('');
                }
            }
        },
        React.createElement('input', {
            className: 'Input-input',
            type: 'text',
            value: value,
            onChange: function onChange(_ref2) {
                var value = _ref2.target.value;
                return setValue(value);
            }
        }),
        React.createElement(
            'button',
            {
                className: 'Input-send',
                onClick: function onClick() {
                    _onClick(value);
                    setValue('');
                }
            },
            'SEND'
        )
    );
};

export default enhance(Input);