// @ts-check
import React from 'react';
import PropTypes from 'prop-types';
import { compose, withStateHandlers } from 'recompose';

import Button from '../Button';

var enhance = compose(withStateHandlers(function (_ref) {
    var _ref$initialState = _ref.initialState,
        initialState = _ref$initialState === undefined ? false : _ref$initialState,
        _ref$initialItems = _ref.initialItems,
        initialItems = _ref$initialItems === undefined ? [] : _ref$initialItems;
    return {
        open: initialState,
        selectedItems: initialItems
    };
}, {
    toggleState: function toggleState(_ref2) {
        var open = _ref2.open;
        return function (_) {
            return {
                open: !open
            };
        };
    },
    toggleItem: function toggleItem(_ref3) {
        var selectedItems = _ref3.selectedItems;
        return function (item) {
            var newItems = [].concat(selectedItems);
            var index = newItems.indexOf(item);
            if (index === -1) {
                newItems.push(item);
            } else {
                newItems.splice(index, 1);
            }
            return { selectedItems: newItems };
        };
    }
}));

/**
 * A menu listing several items. (single choice)
 * @param {Object} param
 * @param {Array<Object>} param.items - The menu items to be displayed
 * @param {function(text: string)} param.submitHandler - submit handler function. This will send a message to the server using data supplied as parameter
 * @return {Object} React component
 */
export var Menu = function Menu(_ref4) {
    var open = _ref4.open,
        toggleState = _ref4.toggleState,
        items = _ref4.items,
        submitHandler = _ref4.submitHandler;
    return React.createElement(
        'div',
        { className: 'Menu ' + (open ? 'is-open' : '') },
        items && React.createElement(
            'ul',
            { className: 'Menu-items' },
            items.map(function (item, i) {
                return React.createElement(
                    'li',
                    {
                        className: 'Menu-item',
                        key: i,
                        onClick: function onClick() {
                            submitHandler(item.text);
                            toggleState();
                        }
                    },
                    item.text
                );
            })
        ),
        React.createElement(
            'button',
            { className: 'Menu-button', onClick: toggleState },
            React.createElement('div', { className: 'Menu-buttonSegment' }),
            React.createElement('div', { className: 'Menu-buttonSegment' }),
            React.createElement('div', { className: 'Menu-buttonSegment' })
        )
    );
};

/**
 * A menu listing several checkbox items. (multiple choice)
 * @param {Object} param
 * @param {Array<Object>} param.items - The menu items to be displayed
 * @param {function(items: Array<string>)} param.submitHandler - submit handler function. This will send a message to the server using data supplied as parameter
 * @return {Object} React component
 */
export var CheckboxMenu = enhance(function (_ref5) {
    var open = _ref5.open,
        toggleState = _ref5.toggleState,
        items = _ref5.items,
        submitHandler = _ref5.submitHandler,
        toggleItem = _ref5.toggleItem,
        selectedItems = _ref5.selectedItems;
    return React.createElement(
        'div',
        { className: 'Menu CheckboxMenu ' + (open ? 'is-open' : '') },
        items && React.createElement(
            'ul',
            { className: 'Menu-items' },
            items.map(function (item, i) {
                return React.createElement(
                    'li',
                    {
                        className: 'Menu-item CheckboxMenu-item',
                        key: i,
                        onClick: function onClick() {
                            return toggleItem(item.text);
                        }
                    },
                    React.createElement('input', {
                        className: 'CheckboxMenu-checkbox',
                        type: 'checkbox',
                        checked: selectedItems.includes(item.text)
                    }),
                    React.createElement(
                        'label',
                        { className: 'CheckboxMenu-label' },
                        item.text
                    )
                );
            })
        ),
        React.createElement(
            'button',
            {
                className: 'CheckboxMenu-submitButton',
                onClick: function onClick() {
                    submitHandler(selectedItems);
                    toggleState();
                }
            },
            'SEND'
        ),
        React.createElement(
            'button',
            { className: 'Menu-button', onClick: toggleState },
            React.createElement('div', { className: 'Menu-buttonSegment' }),
            React.createElement('div', { className: 'Menu-buttonSegment' }),
            React.createElement('div', { className: 'Menu-buttonSegment' })
        )
    );
});

export default enhance(Menu);