//@ts-check
import React from 'react';
import PropTypes from 'prop-types';
import { compose, setPropTypes } from 'recompose';
import { CSSTransition } from 'react-transition-group';

import { Fade } from '../Animation/index';

var createMarkup = function createMarkup(children, title) {
    var text = title ? '<h1 class="Text-h1">' + children + '</h1>' : children;
    return { __html: text };
};

var enhance = compose(setPropTypes({
    title: PropTypes.string,
    isLocal: PropTypes.bool
}));

/**
 * A simple text component for use inside messages.
 * @param {Object} param
 * @param {string} param.title - the text message's title.
 * @param {string} param.children - markdown-generated html to render.  
 * @return {Object} React component
 */
var Text = function Text(_ref) {
    var title = _ref.title,
        children = _ref.children,
        isLocal = _ref.isLocal;
    return React.createElement(
        Fade,
        { 'in': true, appear: true },
        React.createElement('div', {
            className: 'Text ' + (isLocal ? 'is-local' : ''),
            dangerouslySetInnerHTML: createMarkup(children, title)
        })
    );
};

export default enhance(Text);