function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

// @ts-check
import { MESSAGE_ADD, MESSAGE_SEND, PASSTHROUGH_SEND, PASSTHROUGH_RECEIVE } from '../actionTypes';

import * as connectionActions from '../actions/connection';
import * as messageActions from '../actions/messages';

/** A general network manager utility class that handles message sending and receiving through a supplied transport */

var NetworkManager = function () {
	/**
     * Create a point.
     * @param {object} arguments
     * @param {object} arguments.store - The redux store to dispatch actions against
     * @param {object} arguments.client - The transport client to use for network communication
     */
	function NetworkManager(_ref) {
		var store = _ref.store,
		    client = _ref.client;

		_classCallCheck(this, NetworkManager);

		this.dispatch = store.dispatch;
		this.client = client;
		this.store = store;

		this.messageSendHandler = this.messageSendHandler.bind(this);
		this.passThroughSendHandler = this.passThroughSendHandler.bind(this);
	}

	/**
     * Initilise the network transport and bind event handlers
     */


	NetworkManager.prototype.init = function init() {
		var _this = this;

		this.client.init({
			message: this.messageReceiveHandler.bind(this),
			passThrough: this.passThroughReceiveHandler.bind(this),
			connection: {
				close: this.connectionCloseHandler.bind(this),
				attempt: this.connectionAttemptHandler.bind(this),
				open: this.connectionOpenHandler.bind(this)
			}
		}).then(function () {
			return _this.bindActionEvents();
		});
	};

	NetworkManager.prototype.messageReceiveHandler = function messageReceiveHandler(message) {
		this.dispatch(messageActions.messageReceive(message));
	};

	NetworkManager.prototype.passThroughReceiveHandler = function passThroughReceiveHandler(message) {
		this.dispatch({
			type: PASSTHROUGH_RECEIVE,
			payload: message
		});
	};

	NetworkManager.prototype.connectionOpenHandler = function connectionOpenHandler() {
		this.dispatch(connectionActions.established());
	};

	NetworkManager.prototype.connectionCloseHandler = function connectionCloseHandler() {
		this.dispatch(connectionActions.dropped());
	};

	NetworkManager.prototype.connectionAttemptHandler = function connectionAttemptHandler() {
		this.dispatch(connectionActions.attempted());
	};

	NetworkManager.prototype.messageSendHandler = function messageSendHandler(_ref2) {
		var payload = _ref2.detail.payload;

		this.client.send(payload);
	};

	NetworkManager.prototype.passThroughSendHandler = function passThroughSendHandler(_ref3) {
		var payload = _ref3.detail.payload;

		this.client.send(payload);
	};

	/**
     * Add global event handlers for messages/passthroughs triggered outside of RWC.
     */


	NetworkManager.prototype.bindActionEvents = function bindActionEvents() {
		var eventNamespace = this.store.getState().config.network.eventNamespace;

		window.addEventListener(eventNamespace + '-' + MESSAGE_SEND, this.messageSendHandler);
		window.addEventListener(eventNamespace + '-' + PASSTHROUGH_SEND, this.passThroughSendHandler);
	};

	return NetworkManager;
}();

export default NetworkManager;