'use strict';

exports.__esModule = true;
exports.ReactWebChatComponent = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _store = require('./store');

var _lodash = require('lodash');

var _reactRedux = require('react-redux');

require('smoothscroll-polyfill');

var _ChatContainer = require('./components/ChatContainer');

var _ChatContainer2 = _interopRequireDefault(_ChatContainer);

var _actionTypes = require('./actionTypes');

var actionTypes = _interopRequireWildcard(_actionTypes);

var _rwcFeersumClient = require('rwc-feersum-client');

var _rwcFeersumClient2 = _interopRequireDefault(_rwcFeersumClient);

var _network = require('./utils/network');

var _network2 = _interopRequireDefault(_network);

var _default = require('./themes/default');

var _default2 = _interopRequireDefault(_default);

var _config = require('./config');

var _config2 = _interopRequireDefault(_config);

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

/**
 * The main react component for React Web Chat
 * @param {Object} params - An object containing configuration parameters
 * @param {Object} params.theme - Custom theme
 * @param {String} params.url - Chat server url to post messages to
 * @param {Object} params.client - Which client to use for network communication
 * @param {Object} params.typingStatus - A list of configuration options for the typing status indicator
 * @param {Object} params.network - A list of configuration options for network communication
 * @return {Object} React component
 */
var ReactWebChatComponent = exports.ReactWebChatComponent = function ReactWebChatComponent(_ref) {
    var theme = _ref.theme,
        avatar = _ref.avatar,
        client = _ref.client,
        url = _ref.url,
        typingStatus = _ref.typingStatus,
        network = _ref.network;

    var store = (0, _store.createStoreWithState)({
        config: (0, _lodash.merge)({}, _config2.default, { typingStatus: typingStatus }, { network: network }, { avatar: avatar })
    });
    var networkManager = new _network2.default({
        store: store,
        client: client || new _rwcFeersumClient2.default({
            url: url,
            config: {
                channel_id: network.channel_id,
                address: network.address,
                startNew: network.startNew,
                retransmissionTimeout: network.retransmissionTimeout || 500,
                retransmissionMaxTimeout: network.retransmissionMaxTimeout,
                retransmissionAttempts: network.retransmissionAttempts,
                schemaVersion: network.schemaVersion
            }
        })
    });
    networkManager.init();
    return React.createElement(
        _reactRedux.Provider,
        { store: store },
        React.createElement(_ChatContainer2.default, { theme: _extends({}, _default2.default, theme) })
    );
};

/**
 * The wrapping constructor module which renders {@link ReactWebChatComponent} to the target element
 */

var ReactWebChat = function () {
    function ReactWebChat() {
        var _ref2 = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {
            theme: _default2.default,
            avatar: avatar,
            client: client,
            element: element,
            url: 'http://localhost:8080/echo',
            typingStatus: typingStatus,
            network: network
        },
            theme = _ref2.theme,
            avatar = _ref2.avatar,
            client = _ref2.client,
            element = _ref2.element,
            url = _ref2.url,
            typingStatus = _ref2.typingStatus,
            network = _ref2.network;

        _classCallCheck(this, ReactWebChat);

        if (element && element.nodeName) {
            /**
             * @type {Element}
             */
            this.element = element;
            /**
             * @type {Object}
             */
            this.client = client;
            this.bindEventsToActions();
            ReactDOM.render(React.createElement(ReactWebChatComponent, {
                theme: theme,
                avatar: avatar || 'http://i.pravatar.cc/300',
                client: client,
                url: url,
                typingStatus: typingStatus,
                network: network
            }), element);
        } else {
            console.error('React Web Chat: expected element passed to constructor to be a DOM node. Received instead: ', element);
        }
    }

    ReactWebChat.prototype.bindEventsToActions = function bindEventsToActions() {
        Object.values(actionTypes).map(function (type) {
            return window.addEventListener('rwc-dispatch-' + type, function (_ref3) {
                var payload = _ref3.detail.payload;
                return store.dispatch({
                    type: type,
                    payload: payload
                });
            });
        });
    };

    return ReactWebChat;
}();

exports.default = ReactWebChat;