'use strict';

exports.__esModule = true;
exports.CheckboxMenu = exports.Menu = undefined;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _recompose = require('recompose');

var _Button = require('../Button');

var _Button2 = _interopRequireDefault(_Button);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// @ts-check
var enhance = (0, _recompose.compose)((0, _recompose.withStateHandlers)(function (_ref) {
    var _ref$initialState = _ref.initialState,
        initialState = _ref$initialState === undefined ? false : _ref$initialState,
        _ref$initialItems = _ref.initialItems,
        initialItems = _ref$initialItems === undefined ? [] : _ref$initialItems;
    return {
        open: initialState,
        selectedItems: initialItems
    };
}, {
    toggleState: function toggleState(_ref2) {
        var open = _ref2.open;
        return function (_) {
            return {
                open: !open
            };
        };
    },
    toggleItem: function toggleItem(_ref3) {
        var selectedItems = _ref3.selectedItems;
        return function (item) {
            var newItems = [].concat(selectedItems);
            var index = newItems.indexOf(item);
            if (index === -1) {
                newItems.push(item);
            } else {
                newItems.splice(index, 1);
            }
            return { selectedItems: newItems };
        };
    }
}));

/**
 * A menu listing several items. (single choice)
 * @param {Object} param
 * @param {Array<Object>} param.items - The menu items to be displayed
 * @param {function(text: string)} param.submitHandler - submit handler function. This will send a message to the server using data supplied as parameter
 * @return {Object} React component
 */
var Menu = exports.Menu = function Menu(_ref4) {
    var open = _ref4.open,
        toggleState = _ref4.toggleState,
        items = _ref4.items,
        submitHandler = _ref4.submitHandler;
    return _react2.default.createElement(
        'div',
        { className: 'Menu ' + (open ? 'is-open' : '') },
        items && _react2.default.createElement(
            'ul',
            { className: 'Menu-items' },
            items.map(function (item, i) {
                return _react2.default.createElement(
                    'li',
                    {
                        className: 'Menu-item',
                        key: i,
                        onClick: function onClick() {
                            submitHandler(item.text);
                            toggleState();
                        }
                    },
                    item.text
                );
            })
        ),
        _react2.default.createElement(
            'button',
            { className: 'Menu-button', onClick: toggleState },
            _react2.default.createElement('div', { className: 'Menu-buttonSegment' }),
            _react2.default.createElement('div', { className: 'Menu-buttonSegment' }),
            _react2.default.createElement('div', { className: 'Menu-buttonSegment' })
        )
    );
};

/**
 * A menu listing several checkbox items. (multiple choice)
 * @param {Object} param
 * @param {Array<Object>} param.items - The menu items to be displayed
 * @param {function(items: Array<string>)} param.submitHandler - submit handler function. This will send a message to the server using data supplied as parameter
 * @return {Object} React component
 */
var CheckboxMenu = exports.CheckboxMenu = enhance(function (_ref5) {
    var open = _ref5.open,
        toggleState = _ref5.toggleState,
        items = _ref5.items,
        submitHandler = _ref5.submitHandler,
        toggleItem = _ref5.toggleItem,
        selectedItems = _ref5.selectedItems;
    return _react2.default.createElement(
        'div',
        { className: 'Menu CheckboxMenu ' + (open ? 'is-open' : '') },
        items && _react2.default.createElement(
            'ul',
            { className: 'Menu-items' },
            items.map(function (item, i) {
                return _react2.default.createElement(
                    'li',
                    {
                        className: 'Menu-item CheckboxMenu-item',
                        key: i,
                        onClick: function onClick() {
                            return toggleItem(item.text);
                        }
                    },
                    _react2.default.createElement('input', {
                        className: 'CheckboxMenu-checkbox',
                        type: 'checkbox',
                        checked: selectedItems.includes(item.text)
                    }),
                    _react2.default.createElement(
                        'label',
                        { className: 'CheckboxMenu-label' },
                        item.text
                    )
                );
            })
        ),
        _react2.default.createElement(
            'button',
            {
                className: 'CheckboxMenu-submitButton',
                onClick: function onClick() {
                    submitHandler(selectedItems);
                    toggleState();
                }
            },
            'SEND'
        ),
        _react2.default.createElement(
            'button',
            { className: 'Menu-button', onClick: toggleState },
            _react2.default.createElement('div', { className: 'Menu-buttonSegment' }),
            _react2.default.createElement('div', { className: 'Menu-buttonSegment' }),
            _react2.default.createElement('div', { className: 'Menu-buttonSegment' })
        )
    );
});

exports.default = enhance(Menu);